@@ -105,4 +105,4 @@ class MeanScore(Instances):
         return {'scores': self.scores,
                 'mean_score': sum(self.scores) / len(self.scores),
                 'label': self.label,
-                'instances': [i.__dict__ for i in self.instances.get_all()]}  # TODO: should genbase do this?
+                'instances': self.instances}
