@@ -57,6 +57,11 @@ def success_test_renderer(meta: dict, content: dict, **renderargs) -> str:
 
 
 def metrics_renderer(meta: dict, content: dict, **renderargs) -> str:
+    for label in ['confusion_matrix', 'pos_label', 'neg_label']:
+        content['metrics'].remove(label)
+        for m in content['label_metrics']:
+            _ = m['metrics'].pop(label, None)
+
     html = h('Metrics included')
     html += '<ul>'
     for m in content['metrics']:
@@ -133,12 +138,16 @@ class Render(BaseRender):
         def fmt(k, v) -> str:
             if isinstance(v, list):
                 return '<ul>' + ''.join([f'<li>{fmt(k, v_)}</li>' for v_ in v]) + '</ul>'
-            elif isinstance(v, dict) and '__class__' in v:
-                if v['__class__'].startswith('text_sensitivity.data.random.string'):
-                    options = v['options']
-                    if isinstance(options, str):
-                        options = f'"{options}"'
-                    return f'<kbd>{v["__class__"]}</kbd> ({options})'
+            elif isinstance(v, dict):
+                if 'dataset' in v and 'labels' in v:
+                    html = f'<kbd>{v["__class__"]}</kbd>' if '__class__' in v else ''
+                    return html + format_instances(v['dataset'], label=v['labels'])
+                if '__class__' in v:
+                    if v['__class__'].startswith('text_sensitivity.data.random.string'):
+                        options = v['options']
+                        if isinstance(options, str):
+                            options = f'"{options}"'
+                        return f'<kbd>{v["__class__"]}</kbd> ({options})'
             elif str.lower(k) == 'expectation':
                 return f'<kbd>{v}</kbd>'
             return str(v)
